"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const build_angular_1 = require("@angular-devkit/build-angular");
const build_plugin_1 = require("../build-plugin");
const browser_1 = require("../browser");
const _1 = require("./");
const rxjs_1 = require("rxjs");
jest.mock('../build-plugin');
describe('PluginDevServerBuilder Test', () => {
    let pluginDevServerBuilder;
    const root = 'root';
    const devServerPlugin = 'folder/dev-server.plugin.js';
    const browserPlugin = 'folder/browser.plugin.js';
    const context = {
        workspace: { root },
        architect: { getBuilderConfiguration: () => { } },
    };
    const devServerConfig = {
        root,
        projectType: 'application',
        builder: 'ngx-build-plugin:dev-server',
        options: { plugin: devServerPlugin, browserTarget: 'site:browser' }
    };
    const browserConfig = {
        options: { plugin: browserPlugin }
    };
    beforeEach(() => {
        jest.spyOn(build_angular_1.DevServerBuilder.prototype, 'run').mockReturnValue(rxjs_1.of({ success: true }));
        jest.spyOn(browser_1.PluginBrowserBuilder.prototype, 'buildWebpackConfig').mockReturnValue({ parent: true });
        jest.spyOn(context.architect, 'getBuilderConfiguration').mockReturnValue(browserConfig);
        pluginDevServerBuilder = new _1.PluginDevServerBuilder(context);
    });
    describe('#run', () => {
        beforeEach(() => {
            jest.spyOn(build_plugin_1.BuildPlugin, 'loadPlugin').mockReset();
            jest.spyOn(build_plugin_1.BuildPlugin, 'runHook').mockReset();
            pluginDevServerBuilder.run(devServerConfig).subscribe();
        });
        it('should load the plugin', () => {
            expect(build_plugin_1.BuildPlugin.loadPlugin).toHaveBeenLastCalledWith(devServerConfig.root, devServerConfig.options);
            expect(build_plugin_1.BuildPlugin.loadPlugin.mock.calls[0][1].plugin).toEqual(devServerPlugin);
        });
        it('should run the "pre" plugin hook before the super run is called', () => {
            expect(build_plugin_1.BuildPlugin.runHook).toHaveBeenNthCalledWith(1, build_plugin_1.BuildPlugin.PRE_HOOK, devServerConfig);
        });
        it('should run the "post" plugin hook after the super run is called', () => {
            expect(build_plugin_1.BuildPlugin.runHook).toHaveBeenCalledTimes(2);
            expect(build_plugin_1.BuildPlugin.runHook).toHaveBeenNthCalledWith(2, build_plugin_1.BuildPlugin.POST_HOOK, devServerConfig);
        });
        describe('when plugin is not defined in the dev server options', () => {
            beforeEach(() => {
                delete devServerConfig.options.plugin;
                pluginDevServerBuilder.run(devServerConfig).subscribe();
            });
            it('should load the browser plugin option configuration', () => {
                expect(build_plugin_1.BuildPlugin.loadPlugin.mock.calls[0][1].plugin).toEqual(browserPlugin);
            });
        });
    });
    describe('#buildWebpackConfig', () => {
        const configHookReturnValue = { hook: true };
        beforeEach(() => {
            jest
                .spyOn(build_plugin_1.BuildPlugin, 'runHook')
                .mockReturnValueOnce(configHookReturnValue)
                .mockReturnValueOnce(undefined);
        });
        it('should run the "browser" plugin builder and return the config', () => {
            const webpackConfig = pluginDevServerBuilder.buildWebpackConfig(root, null, null, devServerConfig.options);
            expect(webpackConfig.parent).toBeTruthy();
        });
    });
});
//# sourceMappingURL=index.spec.js.map